@@ -1,6 +1,6 @@
 // This defines the interface to the QsciLexerD class.
 //
-// Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2018 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -21,10 +21,6 @@
 #ifndef QSCILEXERD_H
 #define QSCILEXERD_H
 
-#ifdef __APPLE__
-extern "C++" {
-#endif
-
 #include <QObject>
 
 #include <Qsci/qsciglobal.h>
@@ -243,8 +239,4 @@ private:
     QsciLexerD &operator=(const QsciLexerD &);
 };
 
-#ifdef __APPLE__
-}
-#endif
-
 #endif
